#######
Devilry
#######

.. image:: https://readthedocs.org/projects/devilry/badge/?version=latest
   :target: https://readthedocs.org/projects/devilry/?badge=latest
   :alt: Documentation Status

.. image:: https://travis-ci.org/devilry/devilry-django.png?branch=master
   :alt: Build status
   :target: https://travis-ci.org/devilry/devilry-django


Docs and help
=============
http://devilry.org should always be the starting point when looking for documentation or help.


Develop
=======
If you just want to get up a development environment to test out Devilry on you own machine,
read the developer section of our `developer docs <http://devilry.readthedocs.org>`_.

If you want to use our Docker setup for development, read `not_for_deploy/guides/develop-with-docker.md <not_for_deploy/guides/develop-with-docker.md>`_.


Health
======
The image below shows if our testsuite passes on the ``master`` branch. We do not release stable
versions with test failures. This health indicator is mainly useful for developers, or testers that want to try
out the latest development version.

.. image:: https://travis-ci.org/devilry/devilry-django.png?branch=master
  :alt: Build status
  :target: https://travis-ci.org/devilry/devilry-django

